@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.3.2 date 2006-04-08
+ * version 0.3 date 2006-01-29
  * Copyright 2005-2006 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -7,7 +7,6 @@
 
 #include "arp.h"
 #include "config.h"
-#include "debug.h"
 #include "ethernet.h"
 #include "ip.h"
 #include "macros.h"
@@ -44,10 +43,6 @@ static void ArpSendRequest( unsigned char * pIp )
 {
   struct ArpPacket ArpRequest;
 
-  debug_arp_printf( "send req ip=%u.%u.%u.%u",
-                    ArpRequest.ArpHdr.DestIp[0], ArpRequest.ArpHdr.DestIp[1], 
-                    ArpRequest.ArpHdr.DestIp[2], ArpRequest.ArpHdr.DestIp[3] );
-
   //build ARP request
   ArpRequest.ArpHdr.HwType = htons( 0x0001 ); //ethernet
   ArpRequest.ArpHdr.ProtoType = htons( 0x0800 ); //IP
@@ -133,13 +128,6 @@ void ArpRecv( unsigned char * pData, unsigned short Length ) //(extern)
     ip_cpy( ArpReply.ArpHdr.SrcIp, ConfigIp ); //own IP
     mac_cpy( ArpReply.ArpHdr.DestMac, pArpPack->ArpHdr.SrcMac ); //requestor's MAC
     ip_cpy( ArpReply.ArpHdr.DestIp, pArpPack->ArpHdr.SrcIp ); //requestor's IP
-
-    debug_arp_printf( "recv req src=%02X:%02X:%02X:%02X:%02X:%02X ip=%u.%u.%u.%u",
-                      pArpPack->ArpHdr.SrcMac[0], pArpPack->ArpHdr.SrcMac[1], pArpPack->ArpHdr.SrcMac[2],
-                      pArpPack->ArpHdr.SrcMac[3], pArpPack->ArpHdr.SrcMac[4], pArpPack->ArpHdr.SrcMac[5],
-                      pArpPack->ArpHdr.SrcIp[0], pArpPack->ArpHdr.SrcIp[1], 
-                      pArpPack->ArpHdr.SrcIp[2], pArpPack->ArpHdr.SrcIp[3] );
-
     //sent ARP reply
     mac_cpy( ArpReply.EthHdr.Dest, ArpReply.ArpHdr.DestMac ); //ethernet destination address
     ArpReply.EthHdr.Type = htons( 0x0806 ); //ethernet packet type: ARP
@@ -153,13 +141,6 @@ void ArpRecv( unsigned char * pData, unsigned short Length ) //(extern)
       ip_eq( pArpPack->ArpHdr.DestIp, ConfigIp ) ) //own IP address
   {
     unsigned char i;
-
-    debug_arp_printf( "recv reply src=%02X:%02X:%02X:%02X:%02X:%02X ip=%u.%u.%u.%u",
-                      pArpPack->ArpHdr.SrcMac[0], pArpPack->ArpHdr.SrcMac[1], pArpPack->ArpHdr.SrcMac[2],
-                      pArpPack->ArpHdr.SrcMac[3], pArpPack->ArpHdr.SrcMac[4], pArpPack->ArpHdr.SrcMac[5],
-                      pArpPack->ArpHdr.SrcIp[0], pArpPack->ArpHdr.SrcIp[1], 
-                      pArpPack->ArpHdr.SrcIp[2], pArpPack->ArpHdr.SrcIp[3] );
-
     //search IP in ARP tabale
     for( i = 0; i < count( ArpTab ); i++ )
       if( (ArpTab[i].Flags & ArpTabFlagInUse) &&
