@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.3.2 date 2006-04-08
+ * version 0.3 date 2006-01-29
  * Copyright 2005-2006 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -7,7 +7,6 @@
 
 #include "arp.h"
 #include "config.h"
-#include "debug.h"
 #include "ethernet.h"
 #include "ip.h"
 #include "macros.h"
@@ -27,11 +26,6 @@ void EthernetRecv( unsigned char * pData, unsigned short Length ) //(extern)
   //(this saves us from always casting pData)
   pEthPack = (struct EthernetPacket *)pData;
 
-  debug_ether_printf( "recv len=%u type=0x%04X src=%02X:%02X:%02X:%02X:%02X:%02X",
-                      Length, ntohs( pEthPack->EthHdr.Type ),
-                      pEthPack->EthHdr.Src[0], pEthPack->EthHdr.Src[1], pEthPack->EthHdr.Src[2],
-                      pEthPack->EthHdr.Src[3], pEthPack->EthHdr.Src[4], pEthPack->EthHdr.Src[5] ); 
-
   //branch according to packet type
   switch( pEthPack->EthHdr.Type )
   {
@@ -60,11 +54,6 @@ void EthernetSend( unsigned char * pData, unsigned short Length ) //(extern)
   //(this saves us from always casting pData)
   pEthPack = (struct EthernetPacket *)pData;
 
-  debug_ether_printf( "send len=%u type=0x%04X dest=%02X:%02X:%02X:%02X:%02X:%02X",
-                      Length, ntohs( pEthPack->EthHdr.Type ),
-                      pEthPack->EthHdr.Dest[0], pEthPack->EthHdr.Dest[1], pEthPack->EthHdr.Dest[2],
-                      pEthPack->EthHdr.Dest[3], pEthPack->EthHdr.Dest[4], pEthPack->EthHdr.Dest[5] ); 
-
   //fill in source address
   mac_cpy( pEthPack->EthHdr.Src, ConfigMac );
 
