@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.3.2 date 2006-04-08
+ * version 0.3 date 2006-01-29
  * Copyright 2005-2006 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -8,7 +8,6 @@
 #include <string.h>
 #include <avr/pgmspace.h>
 
-#include "debug.h"
 #include "http.h"
 #include "macros.h"
 #include "output.h"
@@ -486,8 +485,6 @@ void HttpConnect( unsigned char ConnNo )
   //get pointer to connection
   pConn = &HttpConns[i];
 
-  debug_http_printf( "accept no=%u", ConnNo );
-
   //put new connection into table
   pConn->ConnNo = ConnNo;
   pConn->RcvCnt = 0;
@@ -511,8 +508,6 @@ void HttpClose( unsigned char ConnNo )
   //get pointer to connection
   pConn = &HttpConns[i];
 
-  debug_http_printf( "close no=%u", ConnNo );
-
   //drop connection from table
   pConn->ConnNo = 0xFF;
 }
@@ -601,7 +596,6 @@ unsigned short HttpSend( unsigned char ConnNo, unsigned long Pos, unsigned char
   } //for( j ...
 
   //return length of data in buffer
-  debug_http_printf( "send no=%u pos=%lu len=%u", ConnNo, Pos, len );
   return len;
 }
 
@@ -660,7 +654,6 @@ unsigned short HttpReceived( unsigned char ConnNo, unsigned long Pos, unsigned c
           pConn->PreHttp1 = 1; //older than HTTP 1.0
           pConn->File = HTTP_FILE_INDEX; //send index file
           pConn->RcvState = HTTP_RCV_DONE; //receiving completed
-          debug_http_printf( "get+end no=%u", pConn->ConnNo );
           pConn->RcvBufLen = 0; //empty receive buffer
           HttpProcessRequest( pConn ); //now process request
         }
@@ -669,7 +662,6 @@ unsigned short HttpReceived( unsigned char ConnNo, unsigned long Pos, unsigned c
           pConn->RcvBufLen--; //remove whitespace from buffer
           HttpParseCommand( pConn ); //parse command
           pConn->RcvState = HTTP_RCV_FILE; //now receive filename
-          debug_http_printf( "get no=%u", pConn->ConnNo );
           pConn->RcvBufLen = 0; //empty receive buffer
         }
         break;
@@ -682,7 +674,6 @@ unsigned short HttpReceived( unsigned char ConnNo, unsigned long Pos, unsigned c
           HttpParseFile( pConn ); //parse file
           pConn->PreHttp1 = 1; //older than HTTP 1.0
           pConn->RcvState = HTTP_RCV_DONE; //receiving completed
-          debug_http_printf( "file+end no=%u file=%u", pConn->ConnNo, pConn->File );
           pConn->RcvBufLen = 0; //empty receive buffer
           HttpProcessRequest( pConn ); //now process request
         }
@@ -692,7 +683,6 @@ unsigned short HttpReceived( unsigned char ConnNo, unsigned long Pos, unsigned c
           HttpParseFile( pConn ); //parse file
           pConn->PreHttp1 = 0; //HTTP 1.0 or newer
           pConn->RcvState = HTTP_RCV_HDR_END; //now receive header until end
-          debug_http_printf( "file no=%u file=%u", pConn->ConnNo, pConn->File );
           pConn->RcvBufLen = 0; //empty receive buffer
         }
         break;
@@ -711,7 +701,6 @@ unsigned short HttpReceived( unsigned char ConnNo, unsigned long Pos, unsigned c
             pConn->RcvBufLen == 4 ) //CR LF CR LF (or some other combination of 4 times CR or LF)
         {
           pConn->RcvState = HTTP_RCV_DONE; //receiving completed
-          debug_http_printf( "end no=%u", pConn->ConnNo );
           pConn->RcvBufLen = 0; //empty receive buffer
           HttpProcessRequest( pConn ); //now process request
         }
