@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.3.2 date 2006-04-08
+ * version 0.3 date 2006-01-29
  * Copyright 2005-2006 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -8,7 +8,6 @@
 #include <string.h>
 
 #include "checksum.h"
-#include "debug.h"
 #include "ethernet.h"
 #include "icmp.h"
 #include "ip.h"
@@ -30,8 +29,6 @@ static void IcmpSend( unsigned char * pData, unsigned short Length )
   //(this saves us from always casting pData)
   pIcmpPack = (struct IcmpPacket *)pData;
 
-  debug_icmp_printf( "send type=0x%02X len=%u", pIcmpPack->IcmpHdr.Type, Length );
-
   //fill in header values
   pIcmpPack->IcmpHdr.Chk = 0x0000;
 
@@ -61,8 +58,6 @@ static void IcmpEchoReqRecv( unsigned char * pData, unsigned short Length )
   if( pIcmpEchoPack->IcmpHdr.Code != 0x00 )
     return;
 
-  debug_icmp_printf( "icmp echo len=%u", Length );
-
   //send an ICMP echo reply
   // - use same buffer to send reply
   // - this saves us from needing to allocate a new buffer
@@ -90,8 +85,6 @@ void IcmpRecv( unsigned char * pData, unsigned short Length ) //(extern)
   if( Checksum( (unsigned char*)&pIcmpPack->IcmpHdr, Length - sizeof( struct EthernetHeader ) - sizeof( struct IpHeader ), 0x0000, 0x0000 ) != 0 )
     return;
 
-  debug_icmp_printf( "recv type=0x%02X len=%u", pIcmpPack->IcmpHdr.Type, Length );
-
   //branch according to type
   switch( pIcmpPack->IcmpHdr.Type )
   {
