@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.3.2 date 2006-04-08
+ * version 0.3 date 2006-01-29
  * Copyright 2005-2006 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -25,20 +25,15 @@
 int main( void )
 {
   wdt_reset( );
-#ifdef DEBUG
-  wdt_disable( );
-#else
   wdt_enable( WDTO_60MS );
-#endif
   wdt_reset( );
 
   //initialize uart to be able to use stdio
   UartInit( );
 
-  debug_printf( "" );
-  debug_printf( "8BitAmEthernet" );
-
-  debug_init_printf( "init" );
+  debug_print( "" );
+  debug_print( "" );
+  debug_print( "init" );
 
   //initialize modules
   ArpInit( );
@@ -50,7 +45,7 @@ int main( void )
   TcpInit( );
   TimingInit( );
 
-  debug_init_printf( "config" );
+  debug_print( "config" );
 
   //get configuration from EEPROM
   EepromGetConfig( );
@@ -58,22 +53,17 @@ int main( void )
   //enable interrupts
   sei( );
 
-  debug_init_printf( "start" );
+  debug_print( "start" );
 
   //main loop
   while( 1 )
   {
     wdt_reset( );
     EepromTask( );
-    wdt_reset( );
     KeypadTask( );
-    wdt_reset( );
     RandomTask( );
-    wdt_reset( );
     RtlTask( );
-    wdt_reset( );
     S8pTask( );
-    wdt_reset( );
     TimingTask( );
   }
 
