@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.3.2 date 2006-04-08
+ * version 0.3 date 2006-01-29
  * Copyright 2005-2006 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -14,17 +14,17 @@
 unsigned char OutputState = 0x00;
 
 //debug output of current output state
-static void OutputDebugOutput( void )
+static void OutputDebugOutput( )
 {
-  debug_output_printf( "output state is now %u %u %u %u %u %u %u %u",
-                       (OutputState & 0x01) != 0x00,
-                       (OutputState & 0x02) != 0x00,
-                       (OutputState & 0x04) != 0x00,
-                       (OutputState & 0x08) != 0x00,
-                       (OutputState & 0x10) != 0x00,
-                       (OutputState & 0x20) != 0x00,
-                       (OutputState & 0x40) != 0x00,
-                       (OutputState & 0x80) != 0x00 );
+  debug_printf( "output state is now %d %d %d %d %d %d %d %d",
+                (OutputState & 0x01) != 0x00,
+                (OutputState & 0x02) != 0x00,
+                (OutputState & 0x04) != 0x00,
+                (OutputState & 0x08) != 0x00,
+                (OutputState & 0x10) != 0x00,
+                (OutputState & 0x20) != 0x00,
+                (OutputState & 0x40) != 0x00,
+                (OutputState & 0x80) != 0x00 );
 }
 
 //initialize
