@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.3.2 date 2006-04-08
+ * version 0.3 date 2006-01-29
  * Copyright 2005-2006 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -38,7 +38,7 @@
  *   "." is the appending operator
  *
  *   commands are identified by their first byte
- *   the status has always got the same first byte as the command
+ *   the status has alwys got the same first byte as the command
  *
  *   get output
  *     command: 0x00 7x<unused>
@@ -61,7 +61,6 @@
 #include <avr/io.h>
 
 #include "config.h"
-#include "debug.h"
 #include "macros.h"
 #include "output.h"
 #include "random.h"
@@ -74,12 +73,14 @@
 
 //states of S8P connections
 #define S8P_FREE 0 //free entry
-#define S8P_NEW 1 //new connection, waiting for challenge to be generated
-#define S8P_CHALLENGE 2 //sending challenge
-#define S8P_RESPONSE 3 //receiving response
-#define S8P_COMMAND 4 //waiting for execution of command
-#define S8P_ACKNOWLEDGE 5 //sending acknowledge
-#define S8P_CLOSE 6 //close connection
+#define S8P_LOCKED 1 //locked entry, in use by non-interrupt-code
+#define S8P_LOCKED_FREE 2 //locked entry, please free when unlocking
+#define S8P_NEW 3 //new connection, waiting for challenge to be generated
+#define S8P_CHALLENGE 4 //sending challenge
+#define S8P_RESPONSE 5 //receiving response
+#define S8P_COMMAND 6 //waiting for execution of command
+#define S8P_ACKNOWLEDGE 7 //sending acknowledge
+#define S8P_CLOSE 8 //close connection
 
 //table with S8P connections
 struct S8pConnection
@@ -107,7 +108,11 @@ void S8pConnect( unsigned char ConnNo )
   if( i < count( S8pConns ) )
   {
     //free this entry
-    S8pConns[i].State = S8P_FREE;
+    if( S8pConns[i].State == S8P_LOCKED ||
+        S8pConns[i].State == S8P_LOCKED_FREE )
+      S8pConns[i].State = S8P_LOCKED_FREE;
+    else
+      S8pConns[i].State = S8P_FREE;
     return;
   }
 
@@ -120,8 +125,6 @@ void S8pConnect( unsigned char ConnNo )
   //get pointer to connection
   pConn = &S8pConns[i];
 
-  debug_s8p_printf( "accept no=%u", ConnNo );
-
   //put new connection into table
   pConn->State = S8P_NEW;
   pConn->ConnNo = ConnNo;
@@ -144,10 +147,12 @@ void S8pClose( unsigned char ConnNo )
   //get pointer to connection
   pConn = &S8pConns[i];
 
-  debug_s8p_printf( "close no=%u", ConnNo );
-
   //drop connection from table
-  pConn->State = S8P_FREE;
+  if( pConn->State == S8P_LOCKED ||
+      pConn->State == S8P_LOCKED_FREE )
+    pConn->State = S8P_LOCKED_FREE;
+  else
+    pConn->State = S8P_FREE;
 }
 
 //called when sending data is possible
@@ -172,10 +177,11 @@ unsigned short S8pSend( unsigned char ConnNo, unsigned long Pos, unsigned char *
   switch( pConn->State )
   {
 
+    case S8P_LOCKED:
+    case S8P_LOCKED_FREE:
     case S8P_NEW:
     case S8P_RESPONSE:
     case S8P_COMMAND:
-      debug_s8p_printf( "send no=%u nothing", ConnNo );
       return 0; //send nothing
 
     case S8P_CHALLENGE: //sending challenge
@@ -183,7 +189,6 @@ unsigned short S8pSend( unsigned char ConnNo, unsigned long Pos, unsigned char *
         return 0; //send nothing
       len = min( sizeof( pConn->Buffer ) - Pos, MaxLen ); //send (part of) challenge
       memcpy( pBuffer, pConn->Buffer + Pos, len );
-      debug_s8p_printf( "send no=%u challenge pos=%lu len=%u", ConnNo, Pos, len );
       return len;
 
     case S8P_ACKNOWLEDGE: //sending acknowledge
@@ -193,7 +198,6 @@ unsigned short S8pSend( unsigned char ConnNo, unsigned long Pos, unsigned char *
         return 0; //send nothing
       len = min( sizeof( pConn->Buffer ) * 2 - Pos, MaxLen ); //send (part of) acknowledge
       memcpy( pBuffer, pConn->Buffer + Pos - sizeof( pConn->Buffer ), len );
-      debug_s8p_printf( "send no=%u acknowledge pos=%lu len=%u", ConnNo, Pos - sizeof( pConn->Buffer ), len );
       return len;
 
     case S8P_CLOSE:
@@ -262,7 +266,6 @@ unsigned short S8pReceived( unsigned char ConnNo, unsigned long Pos, unsigned ch
   {
 
     case S8P_RESPONSE: //receiving response
-      debug_s8p_printf( "recv no=%u response pos=%lu len=%u", ConnNo, Pos, Len );
       if( Pos < sizeof( pConn->Buffer ) ) //not behind response
         memcpy( pConn->Buffer + Pos, pBuffer, min( Len, sizeof( pConn->Buffer ) - Pos ) );
       if( Pos + Len >= sizeof( pConn->Buffer ) ) //entire response is received
@@ -313,6 +316,7 @@ static void S8pCommand( unsigned char Command[8], unsigned char Status[8] )
       break;
 
     //change output
+    //get output
     case 0x01:
       //command: 0x01 <action> <output> 5x<unused>
       OutputChange( Command[1], Command[2] );
@@ -333,7 +337,7 @@ static void S8pCommand( unsigned char Command[8], unsigned char Status[8] )
 void S8pTask( void ) //(extern)
 {
   static unsigned char conn = -1; //used to start serching at another connection each time
-  unsigned char i, req_send, Command[8];
+  unsigned char i, state, req_send, Command[8];
   struct S8pConnection * pConn;
   uint64_t xteaCtx;
 
@@ -349,11 +353,13 @@ void S8pTask( void ) //(extern)
   }
   if( i >= count( S8pConns ) ) //found none
     return;
-  pConn = &S8pConns[i]; //get pointer to connection
+  pConn = &S8pConns[conn]; //ger pointer to connection
+  state = pConn->State; //remember state
+  pConn->State = S8P_LOCKED; //lock connection
 
   //different states
   req_send = 0;
-  switch( pConn->State )
+  switch( state )
   {
 
     //new connection, waiting for challenge to be generated
@@ -369,7 +375,7 @@ void S8pTask( void ) //(extern)
                 (uint64_t *)pConn->Buffer, (uint64_t *)pConn->Buffer,
                 sizeof( pConn->Buffer ) / sizeof( uint64_t ), &xteaCtx );
       //now send challenge
-      pConn->State = S8P_CHALLENGE;
+      state = S8P_CHALLENGE;
       req_send = 1;
       break;
 
@@ -387,33 +393,13 @@ void S8pTask( void ) //(extern)
       //close connection if not
       if( i < sizeof( pConn->Random ) )
       {
-        pConn->State = S8P_CLOSE;
+        state = S8P_CLOSE;
         req_send = 1;
         break;
       }
       //execute command o2, let s be the status returned by this command
       memcpy( Command, pConn->Buffer + sizeof( pConn->Random ), sizeof( Command ) );
-      debug_s8p_printf( "command no=%u %02X %02X %02X %02X %02X %02X %02X %02X",
-                        pConn->ConnNo,
-                        pConn->Buffer[sizeof( pConn->Random ) + 0],
-                        pConn->Buffer[sizeof( pConn->Random ) + 1],
-                        pConn->Buffer[sizeof( pConn->Random ) + 2],
-                        pConn->Buffer[sizeof( pConn->Random ) + 3],
-                        pConn->Buffer[sizeof( pConn->Random ) + 4],
-                        pConn->Buffer[sizeof( pConn->Random ) + 5],
-                        pConn->Buffer[sizeof( pConn->Random ) + 6],
-                        pConn->Buffer[sizeof( pConn->Random ) + 7] );
       S8pCommand( Command, pConn->Buffer + sizeof( pConn->Random ) );
-      debug_s8p_printf( "status no=%u %02X %02X %02X %02X %02X %02X %02X %02X",
-                        pConn->ConnNo,
-                        pConn->Buffer[sizeof( pConn->Random ) + 0],
-                        pConn->Buffer[sizeof( pConn->Random ) + 1],
-                        pConn->Buffer[sizeof( pConn->Random ) + 2],
-                        pConn->Buffer[sizeof( pConn->Random ) + 3],
-                        pConn->Buffer[sizeof( pConn->Random ) + 4],
-                        pConn->Buffer[sizeof( pConn->Random ) + 5],
-                        pConn->Buffer[sizeof( pConn->Random ) + 6],
-                        pConn->Buffer[sizeof( pConn->Random ) + 7] );
       //generate acknowledge: a = ENC_k( ("Status  " XOR d) . s )
       for( i = 0; i < sizeof( pConn->Random ); i++ )
         pConn->Buffer[i] = ((unsigned char *)"Status  ")[i] ^ pConn->Random[i];
@@ -422,14 +408,20 @@ void S8pTask( void ) //(extern)
                 (uint64_t *)pConn->Buffer, (uint64_t *)pConn->Buffer,
                 sizeof( pConn->Buffer ) / sizeof( uint64_t ), &xteaCtx );
       //now send acknowledge
-      pConn->State = S8P_ACKNOWLEDGE;
+      state = S8P_ACKNOWLEDGE;
       req_send = 1;
       break;
 
-  } //switch( pConn->State )
+  } //switch( state )
 
-  //request to send next packet
-  if( req_send )
-    TcpSend( pConn->ConnNo );
+  //unlock connection
+  if( pConn->State == S8P_LOCKED_FREE ) //connection freed by interrupt while locked
+    pConn->State = S8P_FREE; //free it now
+  else
+  {
+    pConn->State = state; //restore original (or modified) state
+    if( req_send ) //request to send next packet
+      TcpSend( pConn->ConnNo );
+  }
 }
 
