@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.3.2 date 2006-04-08
+ * version 0.3 date 2006-01-29
  * Copyright 2005-2006 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -9,7 +9,6 @@
 
 #include "config.h"
 #include "checksum.h"
-#include "debug.h"
 #include "ethernet.h"
 #include "http.h"
 #include "ip.h"
@@ -27,7 +26,7 @@
 #define TCP_FIN 0x01
 #define TCP_FLAGS 0x3F
 
-#define TcpResendTicks 5 //time after which to resend a packet not ACKed (in 200ms steps, max. 255)
+#define TcpResendTicks 5 //time after which to resend a packet not ACKed (in 200ms steps ,max. 255)
 #define TcpTimeWaitTicks 20 //time to wait in TIME_WAIT state (in 200ms steps, max. 255)
 #define TcpTimeoutTicks 50 //maximum idle time of connection before it is reset (in 200ms steps, max. 255)
 #define TcpMaxLifeTimeTicks 150 //maximum lifetime of connection before it is reset (in 200ms steps, max. 255)
@@ -61,17 +60,6 @@ static void TcpSendPacket( unsigned char * pData, unsigned short Length, unsigne
   //(this saves us from always casting pData)
   pTcpPack = (struct TcpPacket *)pData;
 
-  debug_tcp_printf( "send src=%u dest=%u flags=%s%s%s%s%s%s len=%u",
-                    ntohs( pTcpPack->TcpHdr.SrcPort ),
-                    ntohs( pTcpPack->TcpHdr.DestPort ),
-                    flags & TCP_URG ? "U" : "",
-                    flags & TCP_ACK ? "A" : "",
-                    flags & TCP_PSH ? "P" : "",
-                    flags & TCP_RST ? "R" : "",
-                    flags & TCP_SYN ? "S" : "",
-                    flags & TCP_FIN ? "F" : "",
-                    Length );
-
   //fill in header values
   pTcpPack->TcpHdr.Ofs_Flags = htons( (unsigned short)((optLen + 23) & 0x3C) << 10 | (unsigned short)(flags & TCP_FLAGS) );
   pTcpPack->TcpHdr.Chk = 0x0000;
@@ -157,20 +145,15 @@ static void TcpSendDataSegment( unsigned char connNo, struct TcpConnection * pCo
     //get data to send from user
     if( sendDataLen > 0 )
     {
-      debug_tcp_printf( "notify send no=%u pos=%lu max_len=%u",
-                        connNo, pConn->SndNxt - (pConn->Iss + 1), sendDataLen );
       len = pConn->Notify->Send( connNo, pConn->SndNxt - (pConn->Iss + 1), Packet.Data, sendDataLen );
       if( len > sendDataLen ) //returned 0xFFFF (or any number too large) to close connection
       {
-        debug_tcp_printf( "notify send no=%u close", connNo );
         TcpEmptySegment( pConn, pConn->SndNxt, pConn->RcvNxt, TCP_FIN | TCP_ACK ); //send TCP FIN
         pConn->SndNxt++;
         pConn->State = TCP_FIN_WAIT_1; //go to state FIN-WAIT-1
-        debug_tcp_printf( "notify close no=%u", connNo );
         pConn->Notify->Close( connNo ); //signal "connection closed" to user
         return;
       }
-      debug_tcp_printf( "notify send no=%u len=%u", connNo, len );
       sendDataLen = len;
     }
   }
@@ -210,7 +193,7 @@ void TcpTick200( void ) //(extern)
       TcpConns[i].Ticks++;
 
       //get maximum value for normal timer
-      MaxTicks = TcpConns[i].State == TCP_TIME_WAIT ? TcpTimeWaitTicks : TcpResendTicks;
+      MaxTicks = TcpConns[i].State == TCP_TIME_WAIT ? TcpResendTicks : TcpTimeWaitTicks;
       //normal timer elapsed
       if( TcpConns[i].Ticks >= MaxTicks )
       {
@@ -282,7 +265,6 @@ void TcpTick200( void ) //(extern)
           case TCP_ESTAB:
           case TCP_CLOSE_WAIT:
             TcpConns[i].State = TCP_CLOSED; //close connection
-            debug_tcp_printf( "notify close no=%u", i );
             TcpConns[i].Notify->Close( i ); //tell user that connection was closed
             break;
           default:
@@ -311,7 +293,6 @@ void TcpTick200( void ) //(extern)
           case TCP_ESTAB:
           case TCP_CLOSE_WAIT:
             TcpConns[i].State = TCP_CLOSED; //close connection
-            debug_tcp_printf( "notify close no=%u", i );
             TcpConns[i].Notify->Close( i ); //tell user that connection was closed
             break;
           default:
@@ -377,17 +358,6 @@ void TcpRecv( unsigned char * pData, unsigned short Length ) //(extern)
   //get segment length (length of data in segment)
   len = Length - sizeof( struct EthernetHeader ) - sizeof( struct IpHeader ) - ofs;
 
-  debug_tcp_printf( "recv src=%u dest=%u flags=%s%s%s%s%s%s len=%u",
-                    ntohs( pTcpPack->TcpHdr.SrcPort ),
-                    ntohs( pTcpPack->TcpHdr.DestPort ),
-                    flags & TCP_URG ? "U" : "",
-                    flags & TCP_ACK ? "A" : "",
-                    flags & TCP_PSH ? "P" : "",
-                    flags & TCP_RST ? "R" : "",
-                    flags & TCP_SYN ? "S" : "",
-                    flags & TCP_FIN ? "F" : "",
-                    Length );
-
   //process options
   optLen = (unsigned char)(ofs - 20);
   optPtr = (unsigned char *)&pTcpPack->TcpHdr + sizeof( struct TcpHeader );
@@ -458,7 +428,7 @@ void TcpRecv( unsigned char * pData, unsigned short Length ) //(extern)
       pNotify = &S8pNotify;
     }
     //HTTP
-    else if( localPort == ConfigHttpPort )
+    else if( localPort == ConfigWebPort )
     {
       rcvWnd = 256; //connection shall be accepted
       pNotify = &HttpNotify;
@@ -601,7 +571,6 @@ void TcpRecv( unsigned char * pData, unsigned short Length ) //(extern)
         if( (long)(pConn->SndUna - pConn->Iss) > 0 ) //If SND.UNA > ISS (our SYN has been ACKed),
         {
           pConn->State = TCP_ESTAB; //change the connection state to ESTABLISHED,
-          debug_tcp_printf( "notify connect no=%u", connNo );
           pConn->Notify->Connect( connNo ); //signal "connected"
           TcpEmptySegment( pConn, pConn->SndNxt, pConn->RcvNxt, TCP_ACK ); //form an ACK segment and send it.
         }
@@ -689,7 +658,6 @@ void TcpRecv( unsigned char * pData, unsigned short Length ) //(extern)
 
       case TCP_SYN_RCVD:
         pConn->State = TCP_CLOSED; //enter the CLOSED state and delete the TCB, an return.
-        debug_tcp_printf( "notify close no=%u", connNo );
         pConn->Notify->Close( connNo ); //signal "connection refused"
         return;
 
@@ -698,7 +666,6 @@ void TcpRecv( unsigned char * pData, unsigned short Length ) //(extern)
       case TCP_FIN_WAIT_2:
       case TCP_CLOSE_WAIT:
         pConn->State = TCP_CLOSED; //Enter the CLOSED state, delete the TCB, and return.
-        debug_tcp_printf( "notify close no=%u", connNo );
         pConn->Notify->Close( connNo ); //signal "connection reset"
         return;
 
@@ -729,7 +696,6 @@ void TcpRecv( unsigned char * pData, unsigned short Length ) //(extern)
         // - this is always the case here, because SYN not in window would habe been removed above
         TcpEmptySegment( pConn, ack, 0, TCP_RST ); //send a reset,
         pConn->State = TCP_CLOSED; //enter the CLOSED state, delete the TCB, and return.
-        debug_tcp_printf( "notify close no=%u", connNo );
         pConn->Notify->Close( connNo ); //signal "connection reset"
         return;
 
@@ -756,7 +722,6 @@ void TcpRecv( unsigned char * pData, unsigned short Length ) //(extern)
             (long)(ack - pConn->SndNxt) <= 0 )
         {
           pConn->State = TCP_ESTAB; //then enter ESTABLISHED state
-          debug_tcp_printf( "notify connect no=%u", connNo );
           pConn->Notify->Connect( connNo ); //signal "connected"
           //and continue processing.
         }
@@ -789,8 +754,6 @@ void TcpRecv( unsigned char * pData, unsigned short Length ) //(extern)
           pConn->SndWl2 = ack; //and set SND.WL2 <- SEG.ACK.
         }
         pConn->Timeout = 0; //restart timeout timer
-        debug_tcp_printf( "notify sent no=%u pos=%lu",
-                          connNo, pConn->SndNxt - (pConn->Iss + 1) );
         pConn->Notify->Sent( connNo, pConn->SndUna - (pConn->Iss + 1) ); //signal "send completed" (up to ack)
         //additional processing
         switch( pConn->State )
@@ -801,10 +764,7 @@ void TcpRecv( unsigned char * pData, unsigned short Length ) //(extern)
             //no break here
           case TCP_FIN_WAIT_2:
             if( pConn->SndUna == pConn->SndNxt ) //if the retransmission queue is empty,
-            {
-              debug_tcp_printf( "notify close no=%u", connNo );
               pConn->Notify->Close( connNo ); //the user's CLOSE can be acknowledged
-            }
             break;
           case TCP_CLOSING:
             if( pConn->SndUna == pConn->SndNxt ) //if the ACK acknowledges our FIN
@@ -849,12 +809,9 @@ void TcpRecv( unsigned char * pData, unsigned short Length ) //(extern)
         pConn->RcvWnd -= len; //make receive window smaller (len <= pConn->RcvWnd)
         pConn->RcvNxt += len; //advance sequence number of next data to receive
         pConn->Timeout = 0; //restart timeout timer
-        debug_tcp_printf( "notify recv no=%u pos=%lu len=%u, min_wnd=%u",
-                           connNo, pConn->RcvNxt - (pConn->Irs + 1) - len, len, pConn->RcvWnd );
         pConn->RcvWnd = pConn->Notify->Received( connNo, pConn->RcvNxt - (pConn->Irs + 1) - len, //give received data to user
                                                  (unsigned char *)&pTcpPack->TcpHdr + ofs, len, //(update receive window size)
                                                  pConn->RcvWnd );
-        debug_tcp_printf( "notify recv no=%u wnd=%u", connNo, pConn->RcvWnd );
         sendAck = 1; //remember to send an ACK
         break;
 
@@ -877,7 +834,6 @@ void TcpRecv( unsigned char * pData, unsigned short Length ) //(extern)
         TcpEmptySegment( pConn, pConn->SndNxt, pConn->RcvNxt, TCP_FIN | TCP_ACK ); //send a FIN
         pConn->SndNxt++;
         pConn->State = TCP_CLOSING;
-        debug_tcp_printf( "notify close no=%u", connNo );
         pConn->Notify->Close( connNo ); //signal "connection closed" to user
         return; //we do not need to send an ack, becaue we already sent it with our FIN
 
@@ -919,10 +875,6 @@ unsigned char TcpOpen( unsigned char * remoteIp, unsigned short remotePort, //(e
   unsigned short localPort;
   unsigned char i;
 
-  debug_tcp_printf( "open ip=%u.%u.%u.%u port=%u",
-                    remoteIp[0], remoteIp[1], remoteIp[2], remoteIp[3],
-                    remotePort );
-
   //search an unused local port
   for( localPort = nextLocalPort; ; localPort++ )
   {
@@ -966,8 +918,6 @@ unsigned char TcpOpen( unsigned char * remoteIp, unsigned short remotePort, //(e
   TcpConns[i].RcvWnd = initialWnd;
   TcpConns[i].Notify = Notify;
 
-  debug_tcp_printf( "open no=%u", i );
-
   //return connection number
   return i;
 }
@@ -978,8 +928,6 @@ void TcpClose( unsigned char connNo ) //(extern)
 {
   struct TcpConnection * pConn;
 
-  debug_tcp_printf( "close no=%u", connNo );
-
   //connection does not exist
   if( connNo >= count( TcpConns ) || TcpConns[connNo].State == TCP_CLOSED )
     return;
@@ -987,7 +935,7 @@ void TcpClose( unsigned char connNo ) //(extern)
   //get connection
   pConn = &TcpConns[connNo];
 
-  //different actions in different states accroding to RFC793
+  //different actions in different staes accroding to RFC793
   switch( pConn->State  )
   {
 
@@ -1001,7 +949,6 @@ void TcpClose( unsigned char connNo ) //(extern)
       TcpEmptySegment( pConn, pConn->SndNxt, pConn->RcvNxt, TCP_FIN | TCP_ACK ); //form a FIN segment and send it,
       pConn->SndNxt++;
       pConn->State = TCP_FIN_WAIT_1; //and enter FIN-WAIT-1 state;
-      debug_tcp_printf( "notify close no=%u", connNo );
       pConn->Notify->Close( connNo ); //signal "connection closed" to user
       break;
 
@@ -1009,7 +956,6 @@ void TcpClose( unsigned char connNo ) //(extern)
       TcpEmptySegment( pConn, pConn->SndNxt, pConn->RcvNxt, TCP_FIN | TCP_ACK ); //send a FIN segment,
       pConn->SndNxt++;
       pConn->State = TCP_CLOSING; //enter CLOSING state.
-      debug_tcp_printf( "notify close no=%u", connNo );
       pConn->Notify->Close( connNo ); //signal "connection closed" to user
       break;
 
@@ -1023,8 +969,6 @@ void TcpSend( unsigned char connNo ) //(extern)
 {
   struct TcpConnection * pConn;
 
-  debug_tcp_printf( "send no=%u", connNo );
-
   //connection does not exist
   if( connNo >= count( TcpConns ) || TcpConns[connNo].State == TCP_CLOSED )
     return;
