@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.3.2 date 2006-04-08
+ * version 0.3 date 2006-01-29
  * Copyright 2005-2006 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -7,7 +7,6 @@
 
 #include "config.h"
 #include "checksum.h"
-#include "debug.h"
 #include "ethernet.h"
 #include "ip.h"
 #include "macros.h"
@@ -53,18 +52,13 @@ static void UdpEchoRecv( unsigned char * pData, unsigned short Length )
 
   //only reply with allowed packet rate
   if( UdpEchoReplies == 0 )
-  {
-    debug_udp_printf( "echo len=%u (dropped)", Length );
     return;
-  }
   UdpEchoReplies--;
 
-  debug_udp_printf( "echo len=%u", Length );
-
   //send an UDP echo
   // - use same buffer to send reply
-  // - this saves us from allocating a new buffer
-  // - this saves us from copying the data
+  // - this saves us from needing to allocate a new buffer
+  // - this saves us from needing to copy the data
   pUdpPack->UdpHdr.DestPort = pUdpPack->UdpHdr.SrcPort; //back to originationg port
   pUdpPack->UdpHdr.SrcPort = htons( 7 ); //UDP echo port
   ip_cpy( pUdpPack->IpHdr.Dest, pUdpPack->IpHdr.Src ); //back to originating IP
@@ -104,11 +98,6 @@ void UdpRecv( unsigned char * pData, unsigned short Length ) //(extern)
                 ntohs( pUdpPack->UdpHdr.Length ) ) != 0 )
     return;
 
-  debug_udp_printf( "recv src=%u dest=%u len=%u",
-                    ntohs( pUdpPack->UdpHdr.SrcPort ),
-                    ntohs( pUdpPack->UdpHdr.DestPort ),
-                    Length );
-
   //branch according to destination port
   switch( ntohs( pUdpPack->UdpHdr.DestPort ) )
   {
@@ -134,11 +123,6 @@ void UdpSend( unsigned char * pData, unsigned short Length ) //(extern)
   //(this saves us from always casting pData)
   pUdpPack = (struct UdpPacket *)pData;
 
-  debug_udp_printf( "send src=%u dest=%u len=%u",
-                    ntohs( pUdpPack->UdpHdr.SrcPort ),
-                    ntohs( pUdpPack->UdpHdr.DestPort ),
-                    Length );
-
   //fill in header values
   pUdpPack->UdpHdr.Length = htons( Length - sizeof( struct EthernetHeader ) - sizeof( struct IpHeader ) );
   pUdpPack->UdpHdr.Chk = 0x0000;
